@@ -4,9 +4,10 @@ import dataclasses
 from . import bind as _bind
 from . import duration as _duration
 from . import enums as _enums
+from . import format as _format
 from . import get as _get
 from . import indicators as _indicators
-from . import iterate as iterate_
+from . import iterate as _iterate
 from . import lilypondfile as _lilypondfile
 from . import makers as _makers
 from . import metricmodulation as _metricmodulation
@@ -87,7 +88,7 @@ def _illustrate_pitch_range(range_):
         _bind.attach(_indicators.StaffChange("Treble_Staff"), bass_staff[1])
         _bind.attach(_indicators.Clef("treble"), treble_staff[0])
         _bind.attach(_indicators.Clef("bass"), bass_staff[0])
-    for leaf in iterate_.leaves(score):
+    for leaf in _iterate.leaves(score):
         leaf.multiplier = (1, 4)
     _overrides.override(score).BarLine.stencil = False
     _overrides.override(score).SpanBar.stencil = False
@@ -105,7 +106,7 @@ def _illustrate_pitch_segment(segment):
     _overrides.override(score).TimeSignature.stencil = False
     _overrides.override(score).BarLine.stencil = False
     _overrides.override(score).SpanBar.stencil = False
-    for leaf in iterate_.leaves(score):
+    for leaf in _iterate.leaves(score):
         leaf.multiplier = (1, 8)
     _overrides.override(score).Rest.transparent = True
     lilypond_file = _lilypondfile.LilyPondFile([score])
@@ -249,16 +250,17 @@ def illustrate(item, **keywords):
     return method(item, **keywords)
 
 
-def lilypond(argument, tags=False):
+def lilypond(argument, *, site_comments=False, tags=False):
     """
     Gets LilyPond format of ``argument``.
     """
     if not hasattr(argument, "_get_lilypond_format"):
         raise Exception(f"no LilyPond format defined for {argument!r}.")
     string = argument._get_lilypond_format()
-    if tags:
-        return string
-    string = _tag.remove_tags(string)
+    if site_comments is False:
+        string = _format.remove_site_comments(string)
+    if tags is False:
+        string = _tag.remove_tags(string)
     return string
 
 
